@@ -393,11 +393,24 @@ class Document:
             raise TypeError(
                 f"Expected dict for 'raw' argument got {type(raw)} instead")
         metadata = raw['metadata']
-        pages = OrderedDict({page_n: Page(page_number=page_n,
-                                          document_id=metadata['document_id'],
-                                          path=data_path)
-                             for page_n in range(
-                1, metadata['numberOfPages'] + 1)})
+        pages = OrderedDict()
+        for page_n in range(1, metadata['numberOfPages'] + 1):
+            if (
+                    'pages' in raw
+                    and str(page_n) in raw['pages']
+                    and 'width' in raw['pages'][str(page_n)]
+                    and 'height' in raw['pages'][str(page_n)]
+            ):
+                image_width = raw['pages'][str(page_n)]['width']
+                image_height = raw['pages'][str(page_n)]['height']
+            else:
+                image_width = None
+                image_height = None
+            pages[page_n] = Page(page_number=page_n,
+                                 document_id=metadata['document_id'],
+                                 path=data_path,
+                                 image_width=image_width,
+                                 image_height=image_height)
         input_fields = FieldCollection(
             {name: [
                 FieldMapping[
@@ -503,10 +516,10 @@ def annotate_pdf(doc: fitz.Document,
                  opacity: float = 0.3) -> bytes:
     """An annotated Document pdf in bytes"""
     page = doc[tag.page.page_number-1]
-    x0 = tag.left * page.MediaBox.width / 100
-    y0 = tag.top * page.MediaBox.height / 100
-    x1 = tag.right * page.MediaBox.width / 100
-    y1 = tag.bottom * page.MediaBox.height / 100
+    x0 = tag.left * page.mediabox.width / 100
+    y0 = tag.top * page.mediabox.height / 100
+    x1 = tag.right * page.mediabox.width / 100
+    y1 = tag.bottom * page.mediabox.height / 100
     annot_rect = fitz.Rect(x0, y0, x1, y1)
     if color.upper() not in getColorList():
         raise ValueError(f'Wrong color {color}')
