@@ -48,8 +48,9 @@ class TextField(Field):
         :param tags: List of tag objects
         :param field_id: The id of the field
         """
-        super().__init__(name=name, tags=tags, group_key=group_key,
-                         confidence=confidence,  group_name=group_name)
+        super().__init__(name=name, tags=tags, value=value,
+                         group_key=group_key, confidence=confidence,
+                         group_name=group_name)
         self._field_id = field_id
         self._value = '; '.join([i.raw_value
                                  for i in self.tags]) if self.tags else value
